pub enum UpdateFieldLevelEncryptionConfigError {
AccessDenied(String),
IllegalUpdate(String),
InconsistentQuantities(String),
InvalidArgument(String),
InvalidIfMatchVersion(String),
NoSuchFieldLevelEncryptionConfig(String),
NoSuchFieldLevelEncryptionProfile(String),
PreconditionFailed(String),
QueryArgProfileEmpty(String),
TooManyFieldLevelEncryptionContentTypeProfiles(String),
TooManyFieldLevelEncryptionQueryArgProfiles(String),
}Expand description
Errors returned by UpdateFieldLevelEncryptionConfig
Variants
AccessDenied(String)
Access denied.
IllegalUpdate(String)
Origin and CallerReference cannot be updated.
InconsistentQuantities(String)
The value of Quantity and the size of Items don't match.
InvalidArgument(String)
An argument is invalid.
InvalidIfMatchVersion(String)
The If-Match version is missing or not valid for the distribution.
NoSuchFieldLevelEncryptionConfig(String)
The specified configuration for field-level encryption doesn't exist.
NoSuchFieldLevelEncryptionProfile(String)
The specified profile for field-level encryption doesn't exist.
PreconditionFailed(String)
The precondition given in one or more of the request header fields evaluated to false.
QueryArgProfileEmpty(String)
No profile specified for the field-level encryption query argument.
TooManyFieldLevelEncryptionContentTypeProfiles(String)
The maximum number of content type profiles for field-level encryption have been created.
TooManyFieldLevelEncryptionQueryArgProfiles(String)
The maximum number of query arg profiles for field-level encryption have been created.
Implementations