pub enum UpdateFieldLevelEncryptionProfileError {
AccessDenied(String),
FieldLevelEncryptionProfileAlreadyExists(String),
FieldLevelEncryptionProfileSizeExceeded(String),
IllegalUpdate(String),
InconsistentQuantities(String),
InvalidArgument(String),
InvalidIfMatchVersion(String),
NoSuchFieldLevelEncryptionProfile(String),
NoSuchPublicKey(String),
PreconditionFailed(String),
TooManyFieldLevelEncryptionEncryptionEntities(String),
TooManyFieldLevelEncryptionFieldPatterns(String),
}Expand description
Errors returned by UpdateFieldLevelEncryptionProfile
Variants
AccessDenied(String)
Access denied.
FieldLevelEncryptionProfileAlreadyExists(String)
The specified profile for field-level encryption already exists.
FieldLevelEncryptionProfileSizeExceeded(String)
The maximum size of a profile for field-level encryption was exceeded.
IllegalUpdate(String)
Origin and CallerReference cannot be updated.
InconsistentQuantities(String)
The value of Quantity and the size of Items don't match.
InvalidArgument(String)
An argument is invalid.
InvalidIfMatchVersion(String)
The If-Match version is missing or not valid for the distribution.
NoSuchFieldLevelEncryptionProfile(String)
The specified profile for field-level encryption doesn't exist.
NoSuchPublicKey(String)
The specified public key doesn't exist.
PreconditionFailed(String)
The precondition given in one or more of the request header fields evaluated to false.
TooManyFieldLevelEncryptionEncryptionEntities(String)
The maximum number of encryption entities for field-level encryption have been created.
TooManyFieldLevelEncryptionFieldPatterns(String)
The maximum number of field patterns for field-level encryption have been created.
Implementations