pub struct EncryptionEntity {
pub field_patterns: FieldPatterns,
pub provider_id: String,
pub public_key_id: String,
}Expand description
Complex data type for field-level encryption profiles that includes the encryption key and field pattern specifications.
Fields
field_patterns: FieldPatternsField patterns in a field-level encryption content type profile specify the fields that you want to be encrypted. You can provide the full field name, or any beginning characters followed by a wildcard (*). You can't overlap field patterns. For example, you can't have both ABC* and AB*. Note that field patterns are case-sensitive.
provider_id: StringThe provider associated with the public key being used for encryption. This value must also be provided with the private key for applications to be able to decrypt data.
public_key_id: StringThe public key associated with a set of field-level encryption patterns, to be used when encrypting the fields that match the patterns.