pub struct StreamingDistributionList {
pub is_truncated: bool,
pub items: Option<Vec<StreamingDistributionSummary>>,
pub marker: String,
pub max_items: i64,
pub next_marker: Option<String>,
pub quantity: i64,
}Expand description
A streaming distribution list.
Fields
is_truncated: boolA flag that indicates whether more streaming distributions remain to be listed. If your results were truncated, you can make a follow-up pagination request using the Marker request parameter to retrieve more distributions in the list.
items: Option<Vec<StreamingDistributionSummary>>A complex type that contains one StreamingDistributionSummary element for each distribution that was created by the current AWS account.
marker: StringThe value you provided for the Marker request parameter.
max_items: i64The value you provided for the MaxItems request parameter.
next_marker: Option<String>If IsTruncated is true, this element is present and contains the value you can use for the Marker request parameter to continue listing your RTMP distributions where they left off.
quantity: i64The number of streaming distributions that were created by the current AWS account.